import typing
import collections.abc
import typing_extensions

_GenericType1 = typing.TypeVar("_GenericType1")
_GenericType2 = typing.TypeVar("_GenericType2")

def set_from_cli(addons_as_string): ...



import typing
import collections.abc
import typing_extensions
import bpy.types

_GenericType1 = typing.TypeVar("_GenericType1")
_GenericType2 = typing.TypeVar("_GenericType2")

class VertexPaintDirt(bpy.types.Operator):
    """Generate a dirt map gradient based on cavity"""

    bl_idname: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_rna: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        :rtype: bpy.types.Struct
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        :rtype: typing.Any
        """

    def execute(self, context):
        """

        :param context:
        """

    @classmethod
    def poll(cls, context):
        """

        :param context:
        """

def applyVertexDirt(
    me, blur_iterations, blur_strength, clamp_dirt, clamp_clean, dirt_only, normalize
): ...
def ensure_active_color_attribute(me): ...



import typing
import collections.abc
import typing_extensions

_GenericType1 = typing.TypeVar("_GenericType1")
_GenericType2 = typing.TypeVar("_GenericType2")

class NodeCategory:
    @classmethod
    def poll(cls, _context):
        """

        :param _context:
        """

class NodeItem:
    label: typing.Any
    translation_context: typing.Any

    @staticmethod
    def draw(self_, layout, _context):
        """

        :param self_:
        :param layout:
        :param _context:
        """

class NodeItemCustom: ...

def draw_node_categories_menu(self_, context): ...
def has_node_categories(context): ...
def node_categories_iter(context): ...
def node_items_iter(context): ...
def register_node_categories(identifier, cat_list): ...
def unregister_node_cat_types(cats): ...
def unregister_node_categories(identifier=None): ...



import typing
import collections.abc
import typing_extensions

_GenericType1 = typing.TypeVar("_GenericType1")
_GenericType2 = typing.TypeVar("_GenericType2")

def add_scrollback(text, text_type): ...
def autocomplete(_context): ...
def banner(context): ...
def execute(context, _is_interactive): ...
def shell_run(text): ...



import typing
import collections.abc
import typing_extensions

_GenericType1 = typing.TypeVar("_GenericType1")
_GenericType2 = typing.TypeVar("_GenericType2")

def keyconfig_update(keyconfig_data, keyconfig_version): ...



import typing
import collections.abc
import typing_extensions

_GenericType1 = typing.TypeVar("_GenericType1")
_GenericType2 = typing.TypeVar("_GenericType2")

def complete(word: str, namespace: dict, *, private: bool = True) -> list[str]:
    """Complete word within a namespace with the standard rlcompleter
    module. Also supports index or key access [].

        :param word: word to be completed
        :type word: str
        :param namespace: namespace
        :type namespace: dict
        :param private: whether private attribute/methods should be returned
        :type private: bool
        :return: completion matches
        :rtype: list[str]
    """

def complete_indices(
    word: str, namespace: dict, *, obj=None, base: str = None
) -> list[str]:
    """Complete a list or dictionary with its indices:

    :param word: word to be completed
    :type word: str
    :param namespace: namespace
    :type namespace: dict
    :param obj: object evaluated from base
    :param base: sub-string which can be evaluated into an object.
    :type base: str
    :return: completion matches
    :rtype: list[str]
    """

def complete_names(word: str, namespace: dict) -> list[str]:
    """Complete variable names or attributes

    :param word: word to be completed
    :type word: str
    :param namespace: namespace
    :type namespace: dict
    :return: completion matches
    :rtype: list[str]
    """

def is_dict(obj):
    """Returns whether obj is a dictionary"""

def is_struct_seq(obj):
    """Returns whether obj is a structured sequence subclass: sys.float_info"""



import typing
import collections.abc
import typing_extensions
from . import bl_previews_render as bl_previews_render

_GenericType1 = typing.TypeVar("_GenericType1")
_GenericType2 = typing.TypeVar("_GenericType2")



import typing
import collections.abc
import typing_extensions
from . import progress_report as progress_report

_GenericType1 = typing.TypeVar("_GenericType1")
_GenericType2 = typing.TypeVar("_GenericType2")



import typing
import collections.abc
import typing_extensions
from . import text_generate_runtime as text_generate_runtime
from . import url_prefill_runtime as url_prefill_runtime
from . import url_prefill_startup as url_prefill_startup

_GenericType1 = typing.TypeVar("_GenericType1")
_GenericType2 = typing.TypeVar("_GenericType2")



import typing
import collections.abc
import typing_extensions
from . import bl_extract_messages as bl_extract_messages
from . import merge_po as merge_po
from . import settings as settings
from . import utils as utils
from . import utils_cli as utils_cli
from . import utils_languages_menu as utils_languages_menu
from . import utils_rtl as utils_rtl

_GenericType1 = typing.TypeVar("_GenericType1")
_GenericType2 = typing.TypeVar("_GenericType2")



import typing

type FileselectParamsSortItems = typing.Literal[
    "FILE_SORT_ALPHA", "FILE_SORT_EXTENSION", "FILE_SORT_TIME", "FILE_SORT_SIZE"
]
type BrushCurvePresetItems = typing.Literal[
    "CUSTOM",
    "SMOOTH",
    "SMOOTHER",
    "SPHERE",
    "ROOT",
    "SHARP",
    "LIN",
    "POW4",
    "INVSQUARE",
    "CONSTANT",
]
type PropertyTypeItems = typing.Literal[
    "BOOLEAN", "INT", "FLOAT", "STRING", "ENUM", "POINTER", "COLLECTION"
]
type StripColorItems = typing.Literal[
    "NONE",
    "COLOR_01",
    "COLOR_02",
    "COLOR_03",
    "COLOR_04",
    "COLOR_05",
    "COLOR_06",
    "COLOR_07",
    "COLOR_08",
    "COLOR_09",
]
type DriverTargetRotationModeItems = typing.Literal[
    "AUTO",
    "XYZ",
    "XZY",
    "YXZ",
    "YZX",
    "ZXY",
    "ZYX",
    "QUATERNION",
    "SWING_TWIST_X",
    "SWING_TWIST_Y",
    "SWING_TWIST_Z",
]
type EventTypeItems = typing.Literal[
    "NONE",
    "LEFTMOUSE",
    "MIDDLEMOUSE",
    "RIGHTMOUSE",
    "BUTTON4MOUSE",
    "BUTTON5MOUSE",
    "BUTTON6MOUSE",
    "BUTTON7MOUSE",
    "PEN",
    "ERASER",
    "MOUSEMOVE",
    "INBETWEEN_MOUSEMOVE",
    "TRACKPADPAN",
    "TRACKPADZOOM",
    "MOUSEROTATE",
    "MOUSESMARTZOOM",
    "WHEELUPMOUSE",
    "WHEELDOWNMOUSE",
    "WHEELINMOUSE",
    "WHEELOUTMOUSE",
    "A",
    "B",
    "C",
    "D",
    "E",
    "F",
    "G",
    "H",
    "I",
    "J",
    "K",
    "L",
    "M",
    "N",
    "O",
    "P",
    "Q",
    "R",
    "S",
    "T",
    "U",
    "V",
    "W",
    "X",
    "Y",
    "Z",
    "ZERO",
    "ONE",
    "TWO",
    "THREE",
    "FOUR",
    "FIVE",
    "SIX",
    "SEVEN",
    "EIGHT",
    "NINE",
    "LEFT_CTRL",
    "LEFT_ALT",
    "LEFT_SHIFT",
    "RIGHT_ALT",
    "RIGHT_CTRL",
    "RIGHT_SHIFT",
    "OSKEY",
    "APP",
    "GRLESS",
    "ESC",
    "TAB",
    "RET",
    "SPACE",
    "LINE_FEED",
    "BACK_SPACE",
    "DEL",
    "SEMI_COLON",
    "PERIOD",
    "COMMA",
    "QUOTE",
    "ACCENT_GRAVE",
    "MINUS",
    "PLUS",
    "SLASH",
    "BACK_SLASH",
    "EQUAL",
    "LEFT_BRACKET",
    "RIGHT_BRACKET",
    "LEFT_ARROW",
    "DOWN_ARROW",
    "RIGHT_ARROW",
    "UP_ARROW",
    "NUMPAD_2",
    "NUMPAD_4",
    "NUMPAD_6",
    "NUMPAD_8",
    "NUMPAD_1",
    "NUMPAD_3",
    "NUMPAD_5",
    "NUMPAD_7",
    "NUMPAD_9",
    "NUMPAD_PERIOD",
    "NUMPAD_SLASH",
    "NUMPAD_ASTERIX",
    "NUMPAD_0",
    "NUMPAD_MINUS",
    "NUMPAD_ENTER",
    "NUMPAD_PLUS",
    "F1",
    "F2",
    "F3",
    "F4",
    "F5",
    "F6",
    "F7",
    "F8",
    "F9",
    "F10",
    "F11",
    "F12",
    "F13",
    "F14",
    "F15",
    "F16",
    "F17",
    "F18",
    "F19",
    "F20",
    "F21",
    "F22",
    "F23",
    "F24",
    "PAUSE",
    "INSERT",
    "HOME",
    "PAGE_UP",
    "PAGE_DOWN",
    "END",
    "MEDIA_PLAY",
    "MEDIA_STOP",
    "MEDIA_FIRST",
    "MEDIA_LAST",
    "TEXTINPUT",
    "WINDOW_DEACTIVATE",
    "TIMER",
    "TIMER0",
    "TIMER1",
    "TIMER2",
    "TIMER_JOBS",
    "TIMER_AUTOSAVE",
    "TIMER_REPORT",
    "TIMERREGION",
    "NDOF_MOTION",
    "NDOF_BUTTON_MENU",
    "NDOF_BUTTON_FIT",
    "NDOF_BUTTON_TOP",
    "NDOF_BUTTON_BOTTOM",
    "NDOF_BUTTON_LEFT",
    "NDOF_BUTTON_RIGHT",
    "NDOF_BUTTON_FRONT",
    "NDOF_BUTTON_BACK",
    "NDOF_BUTTON_ISO1",
    "NDOF_BUTTON_ISO2",
    "NDOF_BUTTON_ROLL_CW",
    "NDOF_BUTTON_ROLL_CCW",
    "NDOF_BUTTON_SPIN_CW",
    "NDOF_BUTTON_SPIN_CCW",
    "NDOF_BUTTON_TILT_CW",
    "NDOF_BUTTON_TILT_CCW",
    "NDOF_BUTTON_ROTATE",
    "NDOF_BUTTON_PANZOOM",
    "NDOF_BUTTON_DOMINANT",
    "NDOF_BUTTON_PLUS",
    "NDOF_BUTTON_MINUS",
    "NDOF_BUTTON_V1",
    "NDOF_BUTTON_V2",
    "NDOF_BUTTON_V3",
    "NDOF_BUTTON_SAVE_V1",
    "NDOF_BUTTON_SAVE_V2",
    "NDOF_BUTTON_SAVE_V3",
    "NDOF_BUTTON_1",
    "NDOF_BUTTON_2",
    "NDOF_BUTTON_3",
    "NDOF_BUTTON_4",
    "NDOF_BUTTON_5",
    "NDOF_BUTTON_6",
    "NDOF_BUTTON_7",
    "NDOF_BUTTON_8",
    "NDOF_BUTTON_9",
    "NDOF_BUTTON_10",
    "NDOF_BUTTON_11",
    "NDOF_BUTTON_12",
    "ACTIONZONE_AREA",
    "ACTIONZONE_REGION",
    "ACTIONZONE_FULLSCREEN",
    "XR_ACTION",
]
type RigidbodyObjectTypeItems = typing.Literal["ACTIVE", "PASSIVE"]
type ConstraintTypeItems = typing.Literal[
    "CAMERA_SOLVER",
    "FOLLOW_TRACK",
    "OBJECT_SOLVER",
    "COPY_LOCATION",
    "COPY_ROTATION",
    "COPY_SCALE",
    "COPY_TRANSFORMS",
    "LIMIT_DISTANCE",
    "LIMIT_LOCATION",
    "LIMIT_ROTATION",
    "LIMIT_SCALE",
    "MAINTAIN_VOLUME",
    "TRANSFORM",
    "TRANSFORM_CACHE",
    "CLAMP_TO",
    "DAMPED_TRACK",
    "IK",
    "LOCKED_TRACK",
    "SPLINE_IK",
    "STRETCH_TO",
    "TRACK_TO",
    "ACTION",
    "ARMATURE",
    "CHILD_OF",
    "FLOOR",
    "FOLLOW_PATH",
    "PIVOT",
    "SHRINKWRAP",
]
type ImageGeneratedTypeItems = typing.Literal["BLANK", "UV_GRID", "COLOR_GRID"]
type Stereo3DAnaglyphTypeItems = typing.Literal[
    "RED_CYAN", "GREEN_MAGENTA", "YELLOW_BLUE"
]
type MeshSelectModeUvItems = typing.Literal["VERTEX", "EDGE", "FACE", "ISLAND"]
type MetaelemTypeItems = typing.Literal["BALL", "CAPSULE", "PLANE", "ELLIPSOID", "CUBE"]
type WorkspaceObjectModeItems = typing.Literal[
    "OBJECT",
    "EDIT",
    "POSE",
    "SCULPT",
    "VERTEX_PAINT",
    "WEIGHT_PAINT",
    "TEXTURE_PAINT",
    "PARTICLE_EDIT",
    "EDIT_GPENCIL",
    "SCULPT_GPENCIL",
    "PAINT_GPENCIL",
    "VERTEX_GPENCIL",
    "WEIGHT_GPENCIL",
]
type RigidbodyObjectShapeItems = typing.Literal[
    "BOX", "SPHERE", "CAPSULE", "CYLINDER", "CONE", "CONVEX_HULL", "MESH", "COMPOUND"
]
type BakePassTypeItems = typing.Literal[
    "COMBINED",
    "AO",
    "SHADOW",
    "POSITION",
    "NORMAL",
    "UV",
    "ROUGHNESS",
    "EMIT",
    "ENVIRONMENT",
    "DIFFUSE",
    "GLOSSY",
    "TRANSMISSION",
]
type ProportionalFalloffCurveOnlyItems = typing.Literal[
    "SMOOTH", "SPHERE", "ROOT", "INVERSE_SQUARE", "SHARP", "LINEAR"
]
type ContextModeItems = typing.Literal[
    "EDIT_MESH",
    "EDIT_CURVE",
    "EDIT_CURVES",
    "EDIT_SURFACE",
    "EDIT_TEXT",
    "EDIT_ARMATURE",
    "EDIT_METABALL",
    "EDIT_LATTICE",
    "EDIT_GREASE_PENCIL",
    "EDIT_POINT_CLOUD",
    "POSE",
    "SCULPT",
    "PAINT_WEIGHT",
    "PAINT_VERTEX",
    "PAINT_TEXTURE",
    "PARTICLE",
    "OBJECT",
    "PAINT_GPENCIL",
    "EDIT_GPENCIL",
    "SCULPT_GPENCIL",
    "WEIGHT_GPENCIL",
    "VERTEX_GPENCIL",
    "SCULPT_CURVES",
    "PAINT_GREASE_PENCIL",
    "SCULPT_GREASE_PENCIL",
    "WEIGHT_GREASE_PENCIL",
    "VERTEX_GREASE_PENCIL",
]
type PropertyOverrideFlagItems = typing.Literal["LIBRARY_OVERRIDABLE"]
type EventValueItems = typing.Literal[
    "ANY", "PRESS", "RELEASE", "CLICK", "DOUBLE_CLICK", "CLICK_DRAG", "NOTHING"
]
type DtLayersSelectSrcItems = typing.Literal[
    "ACTIVE", "ALL", "BONE_SELECT", "BONE_DEFORM"
]
type WmReportItems = typing.Literal[
    "DEBUG",
    "INFO",
    "OPERATOR",
    "PROPERTY",
    "WARNING",
    "ERROR",
    "ERROR_INVALID_INPUT",
    "ERROR_INVALID_CONTEXT",
    "ERROR_OUT_OF_MEMORY",
]
type IdTypeItems = typing.Literal[
    "ACTION",
    "ARMATURE",
    "BRUSH",
    "CACHEFILE",
    "CAMERA",
    "COLLECTION",
    "CURVE",
    "CURVES",
    "FONT",
    "GREASEPENCIL",
    "GREASEPENCIL_V3",
    "IMAGE",
    "KEY",
    "LATTICE",
    "LIBRARY",
    "LIGHT",
    "LIGHT_PROBE",
    "LINESTYLE",
    "MASK",
    "MATERIAL",
    "MESH",
    "META",
    "MOVIECLIP",
    "NODETREE",
    "OBJECT",
    "PAINTCURVE",
    "PALETTE",
    "PARTICLE",
    "POINTCLOUD",
    "SCENE",
    "SCREEN",
    "SOUND",
    "SPEAKER",
    "TEXT",
    "TEXTURE",
    "VOLUME",
    "WINDOWMANAGER",
    "WORKSPACE",
    "WORLD",
]
type BeztripleInterpolationModeItems = typing.Literal[
    "CONSTANT",
    "LINEAR",
    "BEZIER",
    "SINE",
    "QUAD",
    "CUBIC",
    "QUART",
    "QUINT",
    "EXPO",
    "CIRC",
    "BACK",
    "BOUNCE",
    "ELASTIC",
]
type SpaceFileBrowseModeItems = typing.Literal["FILES", "ASSETS"]
type ColorSetsItems = typing.Literal[
    "DEFAULT",
    "THEME01",
    "THEME02",
    "THEME03",
    "THEME04",
    "THEME05",
    "THEME06",
    "THEME07",
    "THEME08",
    "THEME09",
    "THEME10",
    "THEME11",
    "THEME12",
    "THEME13",
    "THEME14",
    "THEME15",
    "THEME16",
    "THEME17",
    "THEME18",
    "THEME19",
    "THEME20",
    "CUSTOM",
]
type ViewsFormatMultilayerItems = typing.Literal["INDIVIDUAL", "MULTIVIEW"]
type PropertyFlagEnumItems = typing.Literal[
    "HIDDEN", "SKIP_SAVE", "ANIMATABLE", "LIBRARY_EDITABLE", "ENUM_FLAG"
]
type KeyingFlagApiItems = typing.Literal[
    "INSERTKEY_NEEDED",
    "INSERTKEY_VISUAL",
    "INSERTKEY_XYZ_TO_RGB",
    "INSERTKEY_REPLACE",
    "INSERTKEY_AVAILABLE",
    "INSERTKEY_CYCLE_AWARE",
]
type EventDirectionItems = typing.Literal[
    "ANY",
    "NORTH",
    "NORTH_EAST",
    "EAST",
    "SOUTH_EAST",
    "SOUTH",
    "SOUTH_WEST",
    "WEST",
    "NORTH_WEST",
]
type ParticleEditDisconnectedHairBrushItems = typing.Literal[
    "COMB", "SMOOTH", "LENGTH", "CUT", "WEIGHT"
]
type ProportionalFalloffItems = typing.Literal[
    "SMOOTH",
    "SPHERE",
    "ROOT",
    "INVERSE_SQUARE",
    "SHARP",
    "LINEAR",
    "CONSTANT",
    "RANDOM",
]
type SequenceModifierTypeItems = typing.Literal[
    "BRIGHT_CONTRAST",
    "COLOR_BALANCE",
    "CURVES",
    "HUE_CORRECT",
    "MASK",
    "TONEMAP",
    "WHITE_BALANCE",
    "SOUND_EQUALIZER",
]
type AxisFlagXyzItems = typing.Literal["X", "Y", "Z"]
type BrushWeightBrushTypeItems = typing.Literal["DRAW", "BLUR", "AVERAGE", "SMEAR"]
type ObjectModifierTypeItems = typing.Literal[
    "GREASE_PENCIL_VERTEX_WEIGHT_PROXIMITY",
    "DATA_TRANSFER",
    "MESH_CACHE",
    "MESH_SEQUENCE_CACHE",
    "NORMAL_EDIT",
    "WEIGHTED_NORMAL",
    "UV_PROJECT",
    "UV_WARP",
    "VERTEX_WEIGHT_EDIT",
    "VERTEX_WEIGHT_MIX",
    "VERTEX_WEIGHT_PROXIMITY",
    "GREASE_PENCIL_COLOR",
    "GREASE_PENCIL_TINT",
    "GREASE_PENCIL_OPACITY",
    "GREASE_PENCIL_VERTEX_WEIGHT_ANGLE",
    "GREASE_PENCIL_TIME",
    "GREASE_PENCIL_TEXTURE",
    "ARRAY",
    "BEVEL",
    "BOOLEAN",
    "BUILD",
    "DECIMATE",
    "EDGE_SPLIT",
    "NODES",
    "MASK",
    "MIRROR",
    "MESH_TO_VOLUME",
    "MULTIRES",
    "REMESH",
    "SCREW",
    "SKIN",
    "SOLIDIFY",
    "SUBSURF",
    "TRIANGULATE",
    "VOLUME_TO_MESH",
    "WELD",
    "WIREFRAME",
    "GREASE_PENCIL_ARRAY",
    "GREASE_PENCIL_BUILD",
    "GREASE_PENCIL_LENGTH",
    "LINEART",
    "GREASE_PENCIL_MIRROR",
    "GREASE_PENCIL_MULTIPLY",
    "GREASE_PENCIL_SIMPLIFY",
    "GREASE_PENCIL_SUBDIV",
    "GREASE_PENCIL_ENVELOPE",
    "GREASE_PENCIL_OUTLINE",
    "ARMATURE",
    "CAST",
    "CURVE",
    "DISPLACE",
    "HOOK",
    "LAPLACIANDEFORM",
    "LATTICE",
    "MESH_DEFORM",
    "SHRINKWRAP",
    "SIMPLE_DEFORM",
    "SMOOTH",
    "CORRECTIVE_SMOOTH",
    "LAPLACIANSMOOTH",
    "SURFACE_DEFORM",
    "WARP",
    "WAVE",
    "VOLUME_DISPLACE",
    "GREASE_PENCIL_HOOK",
    "GREASE_PENCIL_NOISE",
    "GREASE_PENCIL_OFFSET",
    "GREASE_PENCIL_SMOOTH",
    "GREASE_PENCIL_THICKNESS",
    "GREASE_PENCIL_LATTICE",
    "GREASE_PENCIL_DASH",
    "GREASE_PENCIL_ARMATURE",
    "GREASE_PENCIL_SHRINKWRAP",
    "CLOTH",
    "COLLISION",
    "DYNAMIC_PAINT",
    "EXPLODE",
    "FLUID",
    "OCEAN",
    "PARTICLE_INSTANCE",
    "PARTICLE_SYSTEM",
    "SOFT_BODY",
    "SURFACE",
]
type ParticleEditHairBrushItems = typing.Literal[
    "COMB", "SMOOTH", "ADD", "LENGTH", "PUFF", "CUT", "WEIGHT"
]
type SubdivisionUvSmoothItems = typing.Literal[
    "NONE",
    "PRESERVE_CORNERS",
    "PRESERVE_CORNERS_AND_JUNCTIONS",
    "PRESERVE_CORNERS_JUNCTIONS_AND_CONCAVE",
    "PRESERVE_BOUNDARIES",
    "SMOOTH_ALL",
]
type ObjectAxisItems = typing.Literal[
    "POS_X", "POS_Y", "POS_Z", "NEG_X", "NEG_Y", "NEG_Z"
]
type MotionpathBakeLocationItems = typing.Literal["HEADS", "TAILS"]
type ColorAttributeTypeItems = typing.Literal["FLOAT_COLOR", "BYTE_COLOR"]
type SpaceImageModeAllItems = typing.Literal["VIEW", "UV", "PAINT", "MASK"]
type TransformOrientationItems = typing.Literal[
    "GLOBAL", "LOCAL", "NORMAL", "GIMBAL", "VIEW", "CURSOR", "PARENT"
]
type PropertyFlagItems = typing.Literal[
    "HIDDEN",
    "SKIP_SAVE",
    "SKIP_PRESET",
    "ANIMATABLE",
    "LIBRARY_EDITABLE",
    "PROPORTIONAL",
    "TEXTEDIT_UPDATE",
    "OUTPUT_PATH",
]
type NodeMathItems = typing.Literal[
    "ADD",
    "SUBTRACT",
    "MULTIPLY",
    "DIVIDE",
    "MULTIPLY_ADD",
    "POWER",
    "LOGARITHM",
    "SQRT",
    "INVERSE_SQRT",
    "ABSOLUTE",
    "EXPONENT",
    "MINIMUM",
    "MAXIMUM",
    "LESS_THAN",
    "GREATER_THAN",
    "SIGN",
    "COMPARE",
    "SMOOTH_MIN",
    "SMOOTH_MAX",
    "ROUND",
    "FLOOR",
    "CEIL",
    "TRUNC",
    "FRACT",
    "MODULO",
    "FLOORED_MODULO",
    "WRAP",
    "SNAP",
    "PINGPONG",
    "SINE",
    "COSINE",
    "TANGENT",
    "ARCSINE",
    "ARCCOSINE",
    "ARCTANGENT",
    "ARCTAN2",
    "SINH",
    "COSH",
    "TANH",
    "RADIANS",
    "DEGREES",
]
type NodeClampItems = typing.Literal["MINMAX", "RANGE"]
type ShrinkwrapTypeItems = typing.Literal[
    "NEAREST_SURFACEPOINT", "PROJECT", "NEAREST_VERTEX", "TARGET_PROJECT"
]
type BakeSaveModeItems = typing.Literal["INTERNAL", "EXTERNAL"]
type BoidruleTypeItems = typing.Literal[
    "GOAL",
    "AVOID",
    "AVOID_COLLISION",
    "SEPARATE",
    "FLOCK",
    "FOLLOW_LEADER",
    "AVERAGE_SPEED",
    "FIGHT",
]
type CurveNormalModeItems = typing.Literal["MINIMUM_TWIST", "Z_UP", "FREE"]
type AssetLibraryTypeItems = typing.Literal["ALL", "LOCAL", "ESSENTIALS", "CUSTOM"]
type SequenceVideoModifierTypeItems = typing.Literal[
    "BRIGHT_CONTRAST",
    "COLOR_BALANCE",
    "CURVES",
    "HUE_CORRECT",
    "MASK",
    "TONEMAP",
    "WHITE_BALANCE",
]
type KeyingsetPathGroupingItems = typing.Literal["NAMED", "NONE", "KEYINGSET"]
type LinestyleAlphaModifierTypeItems = typing.Literal[
    "ALONG_STROKE",
    "CREASE_ANGLE",
    "CURVATURE_3D",
    "DISTANCE_FROM_CAMERA",
    "DISTANCE_FROM_OBJECT",
    "MATERIAL",
    "NOISE",
    "TANGENT",
]
type BrushSculptBrushTypeItems = typing.Literal[
    "DRAW",
    "DRAW_SHARP",
    "CLAY",
    "CLAY_STRIPS",
    "CLAY_THUMB",
    "LAYER",
    "INFLATE",
    "BLOB",
    "CREASE",
    "SMOOTH",
    "FLATTEN",
    "FILL",
    "SCRAPE",
    "MULTIPLANE_SCRAPE",
    "PINCH",
    "GRAB",
    "ELASTIC_DEFORM",
    "SNAKE_HOOK",
    "THUMB",
    "POSE",
    "NUDGE",
    "ROTATE",
    "TOPOLOGY",
    "BOUNDARY",
    "CLOTH",
    "SIMPLIFY",
    "MASK",
    "DRAW_FACE_SETS",
    "DISPLACEMENT_ERASER",
    "DISPLACEMENT_SMEAR",
    "PAINT",
    "SMEAR",
]
type AttributeTypeWithAutoItems = typing.Literal[
    "AUTO",
    "FLOAT",
    "INT",
    "FLOAT_VECTOR",
    "FLOAT_COLOR",
    "BYTE_COLOR",
    "STRING",
    "BOOLEAN",
    "FLOAT2",
    "FLOAT2",
    "INT32_2D",
    "QUATERNION",
    "FLOAT4X4",
]
type DtMethodPolyItems = typing.Literal[
    "TOPOLOGY", "NEAREST", "NORMAL", "POLYINTERP_PNORPROJ"
]
type ClipEditorModeItems = typing.Literal["TRACKING", "MASK"]
type NodeCombsepColorItems = typing.Literal["RGB", "HSV", "HSL"]
type TextureTypeItems = typing.Literal[
    "NONE",
    "BLEND",
    "CLOUDS",
    "DISTORTED_NOISE",
    "IMAGE",
    "MAGIC",
    "MARBLE",
    "MUSGRAVE",
    "NOISE",
    "STUCCI",
    "VORONOI",
    "WOOD",
]
type SubdivisionBoundarySmoothItems = typing.Literal["PRESERVE_CORNERS", "ALL"]
type GeometryNodesGizmoColorItems = typing.Literal[
    "PRIMARY", "SECONDARY", "X", "Y", "Z"
]
type NodeSocketDataTypeItems = typing.Literal[
    "FLOAT",
    "INT",
    "BOOLEAN",
    "VECTOR",
    "ROTATION",
    "MATRIX",
    "STRING",
    "MENU",
    "RGBA",
    "OBJECT",
    "IMAGE",
    "GEOMETRY",
    "COLLECTION",
    "TEXTURE",
    "MATERIAL",
]
type LinestyleGeometryModifierTypeItems = typing.Literal[
    "2D_OFFSET",
    "2D_TRANSFORM",
    "BACKBONE_STRETCHER",
    "BEZIER_CURVE",
    "BLUEPRINT",
    "GUIDING_LINES",
    "PERLIN_NOISE_1D",
    "PERLIN_NOISE_2D",
    "POLYGONIZATION",
    "SAMPLING",
    "SIMPLIFICATION",
    "SINUS_DISPLACEMENT",
    "SPATIAL_NOISE",
    "TIP_REMOVER",
]
type LinestyleThicknessModifierTypeItems = typing.Literal[
    "ALONG_STROKE",
    "CALLIGRAPHY",
    "CREASE_ANGLE",
    "CURVATURE_3D",
    "DISTANCE_FROM_CAMERA",
    "DISTANCE_FROM_OBJECT",
    "MATERIAL",
    "NOISE",
    "TANGENT",
]
type NodeSocketInOutItems = typing.Literal["IN", "OUT"]
type DtMethodEdgeItems = typing.Literal[
    "TOPOLOGY", "VERT_NEAREST", "NEAREST", "POLY_NEAREST", "EDGEINTERP_VNORPROJ"
]
type SpaceTypeItems = typing.Literal[
    "EMPTY",
    "VIEW_3D",
    "IMAGE_EDITOR",
    "NODE_EDITOR",
    "SEQUENCE_EDITOR",
    "CLIP_EDITOR",
    "DOPESHEET_EDITOR",
    "GRAPH_EDITOR",
    "NLA_EDITOR",
    "TEXT_EDITOR",
    "CONSOLE",
    "INFO",
    "TOPBAR",
    "STATUSBAR",
    "OUTLINER",
    "PROPERTIES",
    "FILE_BROWSER",
    "SPREADSHEET",
    "PREFERENCES",
]
type PropertyUnitItems = typing.Literal[
    "NONE",
    "LENGTH",
    "AREA",
    "VOLUME",
    "ROTATION",
    "TIME",
    "TIME_ABSOLUTE",
    "VELOCITY",
    "ACCELERATION",
    "MASS",
    "CAMERA",
    "POWER",
    "TEMPERATURE",
    "WAVELENGTH",
    "COLOR_TEMPERATURE",
    "FREQUENCY",
]
type NormalSwizzleItems = typing.Literal[
    "POS_X", "POS_Y", "POS_Z", "NEG_X", "NEG_Y", "NEG_Z"
]
type DtMixModeItems = typing.Literal[
    "REPLACE", "ABOVE_THRESHOLD", "BELOW_THRESHOLD", "MIX", "ADD", "SUB", "MUL"
]
type KeyblockTypeItems = typing.Literal[
    "KEY_LINEAR", "KEY_CARDINAL", "KEY_CATMULL_ROM", "KEY_BSPLINE"
]
type AttributeDomainPointFaceCurveItems = typing.Literal["POINT", "FACE", "CURVE"]
type BakeTargetItems = typing.Literal["IMAGE_TEXTURES", "VERTEX_COLORS"]
type BrushGpencilVertexTypesItems = typing.Literal[
    "DRAW", "BLUR", "AVERAGE", "SMEAR", "REPLACE"
]
type NavigationModeItems = typing.Literal["WALK", "FLY"]
type SnapNodeElementItems = typing.Literal["GRID", "NODE_X", "NODE_Y", "NODE_XY"]
type NodeTreeInterfaceItemTypeItems = typing.Literal["SOCKET", "PANEL"]
type OperatorPropertyTagItems = typing.Literal["ADVANCED"]
type BrushVertexBrushTypeItems = typing.Literal["DRAW", "BLUR", "AVERAGE", "SMEAR"]
type LightTypeItems = typing.Literal["POINT", "SUN", "SPOT", "AREA"]
type GeometryComponentTypeItems = typing.Literal[
    "MESH", "POINTCLOUD", "CURVE", "INSTANCES", "GREASEPENCIL"
]
type MotionpathRangeItems = typing.Literal[
    "KEYS_ALL", "KEYS_SELECTED", "SCENE", "MANUAL"
]
type CurvesTypeItems = typing.Literal["CATMULL_ROM", "POLY", "BEZIER", "NURBS"]
type BrushImageBrushTypeItems = typing.Literal[
    "DRAW", "SOFTEN", "SMEAR", "CLONE", "FILL", "MASK"
]
type ObjectEmptyDrawtypeItems = typing.Literal[
    "PLAIN_AXES", "ARROWS", "SINGLE_ARROW", "CIRCLE", "CUBE", "SPHERE", "CONE", "IMAGE"
]
type NodeMapRangeItems = typing.Literal[
    "LINEAR", "STEPPED", "SMOOTHSTEP", "SMOOTHERSTEP"
]
type BrushGpencilWeightTypesItems = typing.Literal["WEIGHT", "BLUR", "AVERAGE", "SMEAR"]
type PropertySubtypeStringItems = typing.Literal[
    "FILE_PATH", "DIR_PATH", "FILE_NAME", "BYTE_STRING", "PASSWORD", "NONE"
]
type RenderPassTypeItems = typing.Literal[
    "COMBINED",
    "Z",
    "SHADOW",
    "AO",
    "POSITION",
    "NORMAL",
    "VECTOR",
    "OBJECT_INDEX",
    "UV",
    "MIST",
    "EMIT",
    "ENVIRONMENT",
    "MATERIAL_INDEX",
    "DIFFUSE_DIRECT",
    "DIFFUSE_INDIRECT",
    "DIFFUSE_COLOR",
    "GLOSSY_DIRECT",
    "GLOSSY_INDIRECT",
    "GLOSSY_COLOR",
    "TRANSMISSION_DIRECT",
    "TRANSMISSION_INDIRECT",
    "TRANSMISSION_COLOR",
    "SUBSURFACE_DIRECT",
    "SUBSURFACE_INDIRECT",
    "SUBSURFACE_COLOR",
]
type SymmetrizeDirectionItems = typing.Literal[
    "NEGATIVE_X", "POSITIVE_X", "NEGATIVE_Y", "POSITIVE_Y", "NEGATIVE_Z", "POSITIVE_Z"
]
type AttributeTypeItems = typing.Literal[
    "FLOAT",
    "INT",
    "FLOAT_VECTOR",
    "FLOAT_COLOR",
    "BYTE_COLOR",
    "STRING",
    "BOOLEAN",
    "FLOAT2",
    "INT8",
    "INT32_2D",
    "QUATERNION",
    "FLOAT4X4",
]
type TransformPivotFullItems = typing.Literal[
    "BOUNDING_BOX_CENTER",
    "CURSOR",
    "INDIVIDUAL_ORIGINS",
    "MEDIAN_POINT",
    "ACTIVE_ELEMENT",
]
type Stereo3DInterlaceTypeItems = typing.Literal[
    "ROW_INTERLEAVED", "COLUMN_INTERLEAVED", "CHECKERBOARD_INTERLEAVED"
]
type AttributeDomainWithAutoItems = typing.Literal[
    "AUTO", "POINT", "EDGE", "FACE", "CORNER", "CURVE", "INSTANCE", "LAYER"
]
type MappingTypeItems = typing.Literal["POINT", "TEXTURE", "VECTOR", "NORMAL"]
type AttributeDomainOnlyMeshNoCornerItems = typing.Literal["POINT", "EDGE", "FACE"]
type UnpackMethodItems = typing.Literal[
    "REMOVE", "USE_LOCAL", "WRITE_LOCAL", "USE_ORIGINAL", "WRITE_ORIGINAL"
]
type DtLayersSelectDstItems = typing.Literal["ACTIVE", "NAME", "INDEX"]
type SpaceActionModeItems = typing.Literal["DOPESHEET", "TIMELINE"]
type SnapElementItems = typing.Literal[
    "INCREMENT",
    "GRID",
    "VERTEX",
    "EDGE",
    "FACE",
    "VOLUME",
    "EDGE_MIDPOINT",
    "EDGE_PERPENDICULAR",
    "FACE_PROJECT",
    "FACE_NEAREST",
]
type ObjectRotationModeItems = typing.Literal[
    "QUATERNION", "XYZ", "XZY", "YXZ", "YZX", "ZXY", "ZYX", "AXIS_ANGLE"
]
type AttributeDomainEdgeFaceItems = typing.Literal["EDGE", "FACE"]
type KeyframePasteMergeItems = typing.Literal[
    "MIX", "OVER_ALL", "OVER_RANGE", "OVER_RANGE_ALL"
]
type SpaceSequencerViewTypeItems = typing.Literal[
    "SEQUENCER", "PREVIEW", "SEQUENCER_PREVIEW"
]
type LinestyleColorModifierTypeItems = typing.Literal[
    "ALONG_STROKE",
    "CREASE_ANGLE",
    "CURVATURE_3D",
    "DISTANCE_FROM_CAMERA",
    "DISTANCE_FROM_OBJECT",
    "MATERIAL",
    "NOISE",
    "TANGENT",
]
type AttributeDomainItems = typing.Literal[
    "POINT", "EDGE", "FACE", "CORNER", "CURVE", "INSTANCE", "LAYER"
]
type ShadingTypeItems = typing.Literal["WIREFRAME", "SOLID", "MATERIAL", "RENDERED"]
type NodeBooleanMathItems = typing.Literal[
    "AND", "OR", "NOT", "NAND", "NOR", "XNOR", "XOR", "IMPLY", "NIMPLY"
]
type BrushAutomaskingFlagItems = typing.Literal[
    "use_automasking_topology",
    "use_automasking_face_sets",
    "use_automasking_boundary_edges",
    "use_automasking_boundary_face_sets",
    "use_automasking_cavity",
    "use_automasking_cavity_inverted",
    "use_automasking_custom_cavity_curve",
]
type BakeMarginTypeItems = typing.Literal["ADJACENT_FACES", "EXTEND"]
type WmJobTypeItems = typing.Literal[
    "RENDER", "RENDER_PREVIEW", "OBJECT_BAKE", "COMPOSITE", "SHADER_COMPILATION"
]
type ImageColorDepthItems = typing.Literal["8", "10", "12", "16", "32"]
type ModifierShrinkwrapModeItems = typing.Literal[
    "ON_SURFACE", "INSIDE", "OUTSIDE", "OUTSIDE_SURFACE", "ABOVE_SURFACE"
]
type PropertyOverrideFlagCollectionItems = typing.Literal[
    "LIBRARY_OVERRIDABLE", "NO_PROPERTY_NAME", "USE_INSERTION"
]
type ViewsFormatMultiviewItems = typing.Literal["INDIVIDUAL", "STEREO_3D", "MULTIVIEW"]
type ExrCodecItems = typing.Literal[
    "NONE", "PXR24", "ZIP", "PIZ", "RLE", "ZIPS", "B44", "B44A", "DWAA", "DWAB"
]
type NodeVecMathItems = typing.Literal[
    "ADD",
    "SUBTRACT",
    "MULTIPLY",
    "DIVIDE",
    "MULTIPLY_ADD",
    "CROSS_PRODUCT",
    "PROJECT",
    "REFLECT",
    "REFRACT",
    "FACEFORWARD",
    "DOT_PRODUCT",
    "DISTANCE",
    "LENGTH",
    "SCALE",
    "NORMALIZE",
    "ABSOLUTE",
    "MINIMUM",
    "MAXIMUM",
    "FLOOR",
    "CEIL",
    "FRACTION",
    "MODULO",
    "WRAP",
    "SNAP",
    "SINE",
    "COSINE",
    "TANGENT",
]
type NodeSocketTypeItems = typing.Literal[
    "CUSTOM",
    "VALUE",
    "INT",
    "BOOLEAN",
    "VECTOR",
    "ROTATION",
    "MATRIX",
    "STRING",
    "RGBA",
    "SHADER",
    "OBJECT",
    "IMAGE",
    "GEOMETRY",
    "COLLECTION",
    "TEXTURE",
    "MATERIAL",
    "MENU",
]
type FcurveAutoSmoothingItems = typing.Literal["NONE", "CONT_ACCEL"]
type SnapAnimationElementItems = typing.Literal["FRAME", "SECOND", "MARKER"]
type NodeGeometryMeshCircleFillTypeItems = typing.Literal[
    "NONE", "NGON", "TRIANGLE_FAN"
]
type BrushCurvesSculptBrushTypeItems = typing.Literal[
    "SELECTION_PAINT",
    "ADD",
    "DELETE",
    "DENSITY",
    "COMB",
    "SNAKE_HOOK",
    "GROW_SHRINK",
    "PINCH",
    "PUFF",
    "SMOOTH",
    "SLIDE",
]
type OperatorContextItems = typing.Literal[
    "INVOKE_DEFAULT",
    "INVOKE_REGION_WIN",
    "INVOKE_REGION_CHANNELS",
    "INVOKE_REGION_PREVIEW",
    "INVOKE_AREA",
    "INVOKE_SCREEN",
    "EXEC_DEFAULT",
    "EXEC_REGION_WIN",
    "EXEC_REGION_CHANNELS",
    "EXEC_REGION_PREVIEW",
    "EXEC_AREA",
    "EXEC_SCREEN",
]
type NlaModeBlendItems = typing.Literal[
    "REPLACE", "COMBINE", "ADD", "SUBTRACT", "MULTIPLY"
]
type VolumeGridDataTypeItems = typing.Literal[
    "BOOLEAN",
    "FLOAT",
    "DOUBLE",
    "INT",
    "INT64",
    "MASK",
    "VECTOR_FLOAT",
    "VECTOR_DOUBLE",
    "VECTOR_INT",
    "POINTS",
    "UNKNOWN",
]
type ColorSpaceConvertDefaultItems = typing.Literal["NONE"]
type TransformModeTypeItems = typing.Literal[
    "INIT",
    "DUMMY",
    "TRANSLATION",
    "ROTATION",
    "RESIZE",
    "SKIN_RESIZE",
    "TOSPHERE",
    "SHEAR",
    "BEND",
    "SHRINKFATTEN",
    "TILT",
    "TRACKBALL",
    "PUSHPULL",
    "CREASE",
    "VERTEX_CREASE",
    "MIRROR",
    "BONE_SIZE",
    "BONE_ENVELOPE",
    "BONE_ENVELOPE_DIST",
    "CURVE_SHRINKFATTEN",
    "MASK_SHRINKFATTEN",
    "GPENCIL_SHRINKFATTEN",
    "BONE_ROLL",
    "TIME_TRANSLATE",
    "TIME_SLIDE",
    "TIME_SCALE",
    "TIME_EXTEND",
    "BAKE_TIME",
    "BWEIGHT",
    "ALIGN",
    "EDGESLIDE",
    "SEQSLIDE",
    "GPENCIL_OPACITY",
]
type DtMethodVertexItems = typing.Literal[
    "TOPOLOGY",
    "NEAREST",
    "EDGE_NEAREST",
    "EDGEINTERP_NEAREST",
    "POLY_NEAREST",
    "POLYINTERP_NEAREST",
    "POLYINTERP_VNORPROJ",
]
type KeyingFlagItems = typing.Literal[
    "INSERTKEY_NEEDED", "INSERTKEY_VISUAL", "INSERTKEY_XYZ_TO_RGB"
]
type SnapSourceItems = typing.Literal["CLOSEST", "CENTER", "MEDIAN", "ACTIVE"]
type MeshSelectModeItems = typing.Literal["VERT", "EDGE", "FACE"]
type BrushGpencilTypesItems = typing.Literal["DRAW", "FILL", "ERASE", "TINT"]
type CurvesHandleTypeItems = typing.Literal["FREE", "AUTO", "VECTOR", "ALIGN"]
type IconItems = typing.Literal[
    "NONE",
    "BLANK1",
    "AUTOMERGE_OFF",
    "AUTOMERGE_ON",
    "CHECKBOX_DEHLT",
    "CHECKBOX_HLT",
    "CLIPUV_DEHLT",
    "CLIPUV_HLT",
    "DECORATE_UNLOCKED",
    "DECORATE_LOCKED",
    "FAKE_USER_OFF",
    "FAKE_USER_ON",
    "HIDE_ON",
    "HIDE_OFF",
    "INDIRECT_ONLY_OFF",
    "INDIRECT_ONLY_ON",
    "ONIONSKIN_OFF",
    "ONIONSKIN_ON",
    "UNPINNED",
    "PINNED",
    "RADIOBUT_OFF",
    "RADIOBUT_ON",
    "RECORD_OFF",
    "RECORD_ON",
    "RESTRICT_RENDER_ON",
    "RESTRICT_RENDER_OFF",
    "RESTRICT_SELECT_ON",
    "RESTRICT_SELECT_OFF",
    "RESTRICT_VIEW_ON",
    "RESTRICT_VIEW_OFF",
    "RIGHTARROW",
    "DOWNARROW_HLT",
    "SELECT_INTERSECT",
    "SELECT_DIFFERENCE",
    "SNAP_OFF",
    "SNAP_ON",
    "UNLOCKED",
    "LOCKED",
    "VIS_SEL_11",
    "VIS_SEL_10",
    "VIS_SEL_01",
    "VIS_SEL_00",
    "CANCEL",
    "ERROR",
    "QUESTION",
    "ADD",
    "ARROW_LEFTRIGHT",
    "AUTO",
    "BLENDER",
    "BORDERMOVE",
    "BRUSHES_ALL",
    "CHECKMARK",
    "COLLAPSEMENU",
    "COLLECTION_NEW",
    "COLOR",
    "COPY_ID",
    "DISCLOSURE_TRI_DOWN",
    "DISCLOSURE_TRI_RIGHT",
    "DOT",
    "DRIVER_DISTANCE",
    "DRIVER_ROTATIONAL_DIFFERENCE",
    "DRIVER_TRANSFORM",
    "DUPLICATE",
    "EYEDROPPER",
    "FCURVE_SNAPSHOT",
    "FILE_NEW",
    "FILE_TICK",
    "FREEZE",
    "FULLSCREEN_ENTER",
    "FULLSCREEN_EXIT",
    "GHOST_DISABLED",
    "GHOST_ENABLED",
    "GRIP",
    "HAND",
    "HELP",
    "LINKED",
    "MENU_PANEL",
    "NODE_SEL",
    "NODE",
    "OBJECT_HIDDEN",
    "OPTIONS",
    "PANEL_CLOSE",
    "PLUGIN",
    "PLUS",
    "PRESET_NEW",
    "QUIT",
    "RECOVER_LAST",
    "REMOVE",
    "RIGHTARROW_THIN",
    "SCREEN_BACK",
    "STATUSBAR",
    "STYLUS_PRESSURE",
    "THREE_DOTS",
    "TOPBAR",
    "TRASH",
    "TRIA_DOWN",
    "TRIA_LEFT",
    "TRIA_RIGHT",
    "TRIA_UP",
    "UNLINKED",
    "URL",
    "VIEWZOOM",
    "WINDOW",
    "WORKSPACE",
    "X",
    "ZOOM_ALL",
    "ZOOM_IN",
    "ZOOM_OUT",
    "ZOOM_PREVIOUS",
    "ZOOM_SELECTED",
    "MODIFIER",
    "PARTICLES",
    "PHYSICS",
    "SHADERFX",
    "SPEAKER",
    "OUTPUT",
    "SCENE",
    "TOOL_SETTINGS",
    "LIGHT",
    "MATERIAL",
    "TEXTURE",
    "WORLD",
    "ANIM",
    "SCRIPT",
    "GEOMETRY_NODES",
    "TEXT",
    "ACTION",
    "ASSET_MANAGER",
    "CONSOLE",
    "FILEBROWSER",
    "GEOMETRY_SET",
    "GRAPH",
    "IMAGE",
    "INFO",
    "NLA",
    "NODE_COMPOSITING",
    "NODE_MATERIAL",
    "NODE_TEXTURE",
    "NODETREE",
    "OUTLINER",
    "PREFERENCES",
    "PROPERTIES",
    "SEQUENCE",
    "SOUND",
    "SPREADSHEET",
    "TIME",
    "TRACKER",
    "UV",
    "VIEW3D",
    "EDITMODE_HLT",
    "OBJECT_DATAMODE",
    "PARTICLEMODE",
    "POSE_HLT",
    "SCULPTMODE_HLT",
    "TPAINT_HLT",
    "UV_DATA",
    "VPAINT_HLT",
    "WPAINT_HLT",
    "TRACKER_DATA",
    "TRACKING_BACKWARDS_SINGLE",
    "TRACKING_BACKWARDS",
    "TRACKING_CLEAR_BACKWARDS",
    "TRACKING_CLEAR_FORWARDS",
    "TRACKING_FORWARDS_SINGLE",
    "TRACKING_FORWARDS",
    "TRACKING_REFINE_BACKWARDS",
    "TRACKING_REFINE_FORWARDS",
    "TRACKING",
    "GROUP",
    "CONSTRAINT_BONE",
    "CONSTRAINT",
    "ARMATURE_DATA",
    "BONE_DATA",
    "CAMERA_DATA",
    "CURVE_DATA",
    "EMPTY_DATA",
    "FONT_DATA",
    "LATTICE_DATA",
    "LIGHT_DATA",
    "MESH_DATA",
    "META_DATA",
    "PARTICLE_DATA",
    "SHAPEKEY_DATA",
    "SURFACE_DATA",
    "OBJECT_DATA",
    "RENDER_RESULT",
    "RENDERLAYERS",
    "SCENE_DATA",
    "BRUSH_DATA",
    "IMAGE_DATA",
    "LINE_DATA",
    "MATERIAL_DATA",
    "TEXTURE_DATA",
    "WORLD_DATA",
    "ANIM_DATA",
    "BOIDS",
    "CAMERA_STEREO",
    "COMMUNITY",
    "FACE_MAPS",
    "FCURVE",
    "FILE",
    "GREASEPENCIL",
    "GROUP_BONE",
    "GROUP_UVS",
    "GROUP_VCOL",
    "GROUP_VERTEX",
    "LIBRARY_DATA_BROKEN",
    "LIBRARY_DATA_DIRECT",
    "LIBRARY_DATA_OVERRIDE",
    "ORPHAN_DATA",
    "PACKAGE",
    "PRESET",
    "RENDER_ANIMATION",
    "RENDER_STILL",
    "RNA_ADD",
    "RNA",
    "STRANDS",
    "UGLYPACKAGE",
    "MOUSE_LMB",
    "MOUSE_MMB",
    "MOUSE_RMB",
    "MOUSE_MMB_SCROLL",
    "MOUSE_LMB_2X",
    "MOUSE_MOVE",
    "MOUSE_LMB_DRAG",
    "MOUSE_MMB_DRAG",
    "MOUSE_RMB_DRAG",
    "DECORATE_ANIMATE",
    "DECORATE_DRIVER",
    "DECORATE_KEYFRAME",
    "DECORATE_LIBRARY_OVERRIDE",
    "DECORATE_LINKED",
    "DECORATE_OVERRIDE",
    "DECORATE",
    "OUTLINER_COLLECTION",
    "CURVES_DATA",
    "OUTLINER_DATA_ARMATURE",
    "OUTLINER_DATA_CAMERA",
    "OUTLINER_DATA_CURVE",
    "OUTLINER_DATA_CURVES",
    "OUTLINER_DATA_EMPTY",
    "OUTLINER_DATA_FONT",
    "OUTLINER_DATA_GP_LAYER",
    "OUTLINER_DATA_GREASEPENCIL",
    "OUTLINER_DATA_LATTICE",
    "OUTLINER_DATA_LIGHT",
    "OUTLINER_DATA_LIGHTPROBE",
    "OUTLINER_DATA_MESH",
    "OUTLINER_DATA_META",
    "OUTLINER_DATA_POINTCLOUD",
    "OUTLINER_DATA_SPEAKER",
    "OUTLINER_DATA_SURFACE",
    "OUTLINER_DATA_VOLUME",
    "POINTCLOUD_DATA",
    "POINTCLOUD_POINT",
    "VOLUME_DATA",
    "OUTLINER_OB_ARMATURE",
    "OUTLINER_OB_CAMERA",
    "OUTLINER_OB_CURVE",
    "OUTLINER_OB_CURVES",
    "OUTLINER_OB_EMPTY",
    "OUTLINER_OB_FONT",
    "OUTLINER_OB_FORCE_FIELD",
    "OUTLINER_OB_GREASEPENCIL",
    "OUTLINER_OB_GROUP_INSTANCE",
    "OUTLINER_OB_IMAGE",
    "OUTLINER_OB_LATTICE",
    "OUTLINER_OB_LIGHT",
    "OUTLINER_OB_LIGHTPROBE",
    "OUTLINER_OB_MESH",
    "OUTLINER_OB_META",
    "OUTLINER_OB_POINTCLOUD",
    "OUTLINER_OB_SPEAKER",
    "OUTLINER_OB_SURFACE",
    "OUTLINER_OB_VOLUME",
    "GP_MULTIFRAME_EDITING",
    "GP_ONLY_SELECTED",
    "GP_SELECT_BETWEEN_STROKES",
    "GP_SELECT_POINTS",
    "GP_SELECT_STROKES",
    "HOLDOUT_OFF",
    "HOLDOUT_ON",
    "MODIFIER_OFF",
    "MODIFIER_ON",
    "RESTRICT_COLOR_OFF",
    "RESTRICT_COLOR_ON",
    "RESTRICT_INSTANCED_OFF",
    "RESTRICT_INSTANCED_ON",
    "LIGHT_AREA",
    "LIGHT_HEMI",
    "LIGHT_POINT",
    "LIGHT_SPOT",
    "LIGHT_SUN",
    "LIGHTPROBE_PLANE",
    "LIGHTPROBE_SPHERE",
    "LIGHTPROBE_VOLUME",
    "COLOR_BLUE",
    "COLOR_GREEN",
    "COLOR_RED",
    "CONE",
    "CUBE",
    "CURVE_BEZCIRCLE",
    "CURVE_BEZCURVE",
    "CURVE_NCIRCLE",
    "CURVE_NCURVE",
    "CURVE_PATH",
    "CURVES",
    "EMPTY_ARROWS",
    "EMPTY_AXIS",
    "EMPTY_SINGLE_ARROW",
    "MESH_CAPSULE",
    "MESH_CIRCLE",
    "MESH_CONE",
    "MESH_CUBE",
    "MESH_CYLINDER",
    "MESH_GRID",
    "MESH_ICOSPHERE",
    "MESH_MONKEY",
    "MESH_PLANE",
    "MESH_TORUS",
    "MESH_UVSPHERE",
    "META_BALL",
    "META_CAPSULE",
    "META_CUBE",
    "META_ELLIPSOID",
    "META_PLANE",
    "MONKEY",
    "SPHERE",
    "STROKE",
    "SURFACE_NCIRCLE",
    "SURFACE_NCURVE",
    "SURFACE_NCYLINDER",
    "SURFACE_NSPHERE",
    "SURFACE_NSURFACE",
    "SURFACE_NTORUS",
    "TRIA_DOWN_BAR",
    "TRIA_LEFT_BAR",
    "TRIA_RIGHT_BAR",
    "TRIA_UP_BAR",
    "AREA_DOCK",
    "AREA_JOIN_DOWN",
    "AREA_JOIN_LEFT",
    "AREA_JOIN_UP",
    "AREA_JOIN",
    "AREA_SWAP",
    "FORCE_BOID",
    "FORCE_CHARGE",
    "FORCE_CURVE",
    "FORCE_DRAG",
    "FORCE_FLUIDFLOW",
    "FORCE_FORCE",
    "FORCE_HARMONIC",
    "FORCE_LENNARDJONES",
    "FORCE_MAGNETIC",
    "FORCE_TEXTURE",
    "FORCE_TURBULENCE",
    "FORCE_VORTEX",
    "FORCE_WIND",
    "IMAGE_BACKGROUND",
    "IMAGE_PLANE",
    "IMAGE_REFERENCE",
    "RIGID_BODY_CONSTRAINT",
    "RIGID_BODY",
    "SPLIT_HORIZONTAL",
    "SPLIT_VERTICAL",
    "ANCHOR_BOTTOM",
    "ANCHOR_CENTER",
    "ANCHOR_LEFT",
    "ANCHOR_RIGHT",
    "ANCHOR_TOP",
    "NODE_CORNER",
    "NODE_INSERT_OFF",
    "NODE_INSERT_ON",
    "NODE_SIDE",
    "NODE_TOP",
    "SELECT_EXTEND",
    "SELECT_SET",
    "SELECT_SUBTRACT",
    "ALIGN_BOTTOM",
    "ALIGN_CENTER",
    "ALIGN_FLUSH",
    "ALIGN_JUSTIFY",
    "ALIGN_LEFT",
    "ALIGN_MIDDLE",
    "ALIGN_RIGHT",
    "ALIGN_TOP",
    "BOLD",
    "ITALIC",
    "LINENUMBERS_OFF",
    "LINENUMBERS_ON",
    "SCRIPTPLUGINS",
    "SMALL_CAPS",
    "SYNTAX_OFF",
    "SYNTAX_ON",
    "UNDERLINE",
    "WORDWRAP_OFF",
    "WORDWRAP_ON",
    "CON_ACTION",
    "CON_ARMATURE",
    "CON_CAMERASOLVER",
    "CON_CHILDOF",
    "CON_CLAMPTO",
    "CON_DISTLIMIT",
    "CON_FLOOR",
    "CON_FOLLOWPATH",
    "CON_FOLLOWTRACK",
    "CON_KINEMATIC",
    "CON_LOCKTRACK",
    "CON_LOCLIKE",
    "CON_LOCLIMIT",
    "CON_OBJECTSOLVER",
    "CON_PIVOT",
    "CON_ROTLIKE",
    "CON_ROTLIMIT",
    "CON_SAMEVOL",
    "CON_SHRINKWRAP",
    "CON_SIZELIKE",
    "CON_SIZELIMIT",
    "CON_SPLINEIK",
    "CON_STRETCHTO",
    "CON_TRACKTO",
    "CON_TRANSFORM_CACHE",
    "CON_TRANSFORM",
    "CON_TRANSLIKE",
    "HOOK",
    "MOD_ARMATURE",
    "MOD_ARRAY",
    "MOD_BEVEL",
    "MOD_BOOLEAN",
    "MOD_BUILD",
    "MOD_CAST",
    "MOD_CLOTH",
    "MOD_CURVE",
    "MOD_DASH",
    "MOD_DATA_TRANSFER",
    "MOD_DECIM",
    "MOD_DISPLACE",
    "MOD_DYNAMICPAINT",
    "MOD_EDGESPLIT",
    "MOD_ENVELOPE",
    "MOD_EXPLODE",
    "MOD_FLUID",
    "MOD_FLUIDSIM",
    "MOD_HUE_SATURATION",
    "MOD_INSTANCE",
    "MOD_LATTICE",
    "MOD_LENGTH",
    "MOD_LINEART",
    "MOD_MASK",
    "MOD_MESHDEFORM",
    "MOD_MIRROR",
    "MOD_MULTIRES",
    "MOD_NOISE",
    "MOD_NORMALEDIT",
    "MOD_OCEAN",
    "MOD_OFFSET",
    "MOD_OPACITY",
    "MOD_OUTLINE",
    "MOD_PARTICLE_INSTANCE",
    "MOD_PARTICLES",
    "MOD_PHYSICS",
    "MOD_REMESH",
    "MOD_SCREW",
    "MOD_SHRINKWRAP",
    "MOD_SIMPLEDEFORM",
    "MOD_SIMPLIFY",
    "MOD_SKIN",
    "MOD_SMOOTH",
    "MOD_SOFT",
    "MOD_SOLIDIFY",
    "MOD_SUBSURF",
    "MOD_THICKNESS",
    "MOD_TIME",
    "MOD_TINT",
    "MOD_TRIANGULATE",
    "MOD_UVPROJECT",
    "MOD_VERTEX_WEIGHT",
    "MOD_WARP",
    "MOD_WAVE",
    "MOD_WIREFRAME",
    "MODIFIER_DATA",
    "ACTION_SLOT",
    "ACTION_TWEAK",
    "DRIVER",
    "FF",
    "FRAME_NEXT",
    "FRAME_PREV",
    "HANDLE_ALIGNED",
    "HANDLE_AUTO",
    "HANDLE_AUTOCLAMPED",
    "HANDLE_FREE",
    "HANDLE_VECTOR",
    "IPO_BACK",
    "IPO_BEZIER",
    "IPO_BOUNCE",
    "IPO_CIRC",
    "IPO_CONSTANT",
    "IPO_CUBIC",
    "IPO_EASE_IN_OUT",
    "IPO_EASE_IN",
    "IPO_EASE_OUT",
    "IPO_ELASTIC",
    "IPO_EXPO",
    "IPO_LINEAR",
    "IPO_QUAD",
    "IPO_QUART",
    "IPO_QUINT",
    "IPO_SINE",
    "KEY_DEHLT",
    "KEY_HLT",
    "KEYFRAME_HLT",
    "KEYFRAME",
    "KEYINGSET",
    "MARKER_HLT",
    "MARKER",
    "MUTE_IPO_OFF",
    "MUTE_IPO_ON",
    "NEXT_KEYFRAME",
    "NLA_PUSHDOWN",
    "NORMALIZE_FCURVES",
    "ORIENTATION_PARENT",
    "PAUSE",
    "PLAY_REVERSE",
    "PLAY_SOUND",
    "PLAY",
    "PMARKER_ACT",
    "PMARKER_SEL",
    "PMARKER",
    "PREV_KEYFRAME",
    "PREVIEW_RANGE",
    "REC",
    "REW",
    "SOLO_OFF",
    "SOLO_ON",
    "CENTER_ONLY",
    "CURSOR",
    "EDGESEL",
    "FACE_CORNER",
    "FACESEL",
    "INVERSESQUARECURVE",
    "LINCURVE",
    "NOCURVE",
    "PARTICLE_PATH",
    "PARTICLE_POINT",
    "PARTICLE_TIP",
    "PIVOT_ACTIVE",
    "PIVOT_BOUNDBOX",
    "PIVOT_CURSOR",
    "PIVOT_INDIVIDUAL",
    "PIVOT_MEDIAN",
    "PROP_CON",
    "PROP_OFF",
    "PROP_ON",
    "PROP_PROJECTED",
    "RNDCURVE",
    "ROOTCURVE",
    "SHARPCURVE",
    "SMOOTHCURVE",
    "SPHERECURVE",
    "VERTEXSEL",
    "SNAP_EDGE",
    "SNAP_FACE_CENTER",
    "SNAP_FACE_NEAREST",
    "SNAP_FACE",
    "SNAP_GRID",
    "SNAP_INCREMENT",
    "SNAP_MIDPOINT",
    "SNAP_NORMAL",
    "SNAP_PEEL_OBJECT",
    "SNAP_PERPENDICULAR",
    "SNAP_VERTEX",
    "SNAP_VOLUME",
    "STICKY_UVS_DISABLE",
    "STICKY_UVS_LOC",
    "STICKY_UVS_VERT",
    "ORIENTATION_GIMBAL",
    "ORIENTATION_GLOBAL",
    "ORIENTATION_LOCAL",
    "ORIENTATION_NORMAL",
    "ORIENTATION_VIEW",
    "COPYDOWN",
    "FIXED_SIZE",
    "GIZMO",
    "GP_CAPS_FLAT",
    "GP_CAPS_ROUND",
    "NORMALS_FACE",
    "NORMALS_VERTEX_FACE",
    "NORMALS_VERTEX",
    "OBJECT_ORIGIN",
    "ORIENTATION_CURSOR",
    "PASTEDOWN",
    "PASTEFLIPDOWN",
    "PASTEFLIPUP",
    "TRANSFORM_ORIGINS",
    "UV_EDGESEL",
    "UV_FACESEL",
    "UV_ISLANDSEL",
    "UV_SYNC_SELECT",
    "UV_VERTEXSEL",
    "AXIS_FRONT",
    "AXIS_SIDE",
    "AXIS_TOP",
    "GRID",
    "LAYER_ACTIVE",
    "LAYER_USED",
    "LOCKVIEW_OFF",
    "LOCKVIEW_ON",
    "OVERLAY",
    "SHADING_BBOX",
    "SHADING_RENDERED",
    "SHADING_SOLID",
    "SHADING_TEXTURE",
    "SHADING_WIRE",
    "XRAY",
    "VIEW_CAMERA_UNSELECTED",
    "VIEW_CAMERA",
    "VIEW_LOCKED",
    "VIEW_ORTHO",
    "VIEW_PAN",
    "VIEW_PERSPECTIVE",
    "VIEW_UNLOCKED",
    "VIEW_ZOOM",
    "FILE_ALIAS",
    "FILE_FOLDER",
    "FOLDER_REDIRECT",
    "APPEND_BLEND",
    "BACK",
    "BOOKMARKS",
    "CURRENT_FILE",
    "DESKTOP",
    "DISC",
    "DISK_DRIVE",
    "DOCUMENTS",
    "EXPORT",
    "EXTERNAL_DRIVE",
    "FILE_3D",
    "FILE_ARCHIVE",
    "FILE_BACKUP",
    "FILE_BLANK",
    "FILE_BLEND",
    "FILE_CACHE",
    "FILE_FONT",
    "FILE_HIDDEN",
    "FILE_IMAGE",
    "FILE_MOVIE",
    "FILE_PARENT",
    "FILE_REFRESH",
    "FILE_SCRIPT",
    "FILE_SOUND",
    "FILE_TEXT",
    "FILE_VOLUME",
    "FILTER",
    "FONTPREVIEW",
    "FORWARD",
    "HOME",
    "IMGDISPLAY",
    "IMPORT",
    "LINK_BLEND",
    "LONGDISPLAY",
    "LOOP_BACK",
    "LOOP_FORWARDS",
    "NETWORK_DRIVE",
    "NEWFOLDER",
    "SETTINGS",
    "SHORTDISPLAY",
    "SORT_ASC",
    "SORT_DESC",
    "SORTALPHA",
    "SORTBYEXT",
    "SORTSIZE",
    "SORTTIME",
    "SYSTEM",
    "TAG",
    "TEMP",
    "ALIASED",
    "ANTIALIASED",
    "MAT_SPHERE_SKY",
    "MATCLOTH",
    "MATCUBE",
    "MATFLUID",
    "MATPLANE",
    "MATSHADERBALL",
    "MATSPHERE",
    "SEQ_CHROMA_SCOPE",
    "SEQ_HISTOGRAM",
    "SEQ_LUMA_WAVEFORM",
    "SEQ_PREVIEW",
    "SEQ_SEQUENCER",
    "SEQ_SPLITVIEW",
    "SEQ_STRIP_DUPLICATE",
    "SEQ_STRIP_META",
    "IMAGE_ALPHA",
    "IMAGE_RGB_ALPHA",
    "IMAGE_RGB",
    "IMAGE_ZDEPTH",
    "BLENDER_LOGO_LARGE",
    "CANCEL_LARGE",
    "DISC_LARGE",
    "DISK_DRIVE_LARGE",
    "EXTERNAL_DRIVE_LARGE",
    "FILE_FOLDER_LARGE",
    "FILE_LARGE",
    "FILE_PARENT_LARGE",
    "INFO_LARGE",
    "NETWORK_DRIVE_LARGE",
    "QUESTION_LARGE",
    "WARNING_LARGE",
    "KEY_BACKSPACE_FILLED",
    "KEY_BACKSPACE",
    "KEY_COMMAND_FILLED",
    "KEY_COMMAND",
    "KEY_CONTROL_FILLED",
    "KEY_CONTROL",
    "KEY_EMPTY1_FILLED",
    "KEY_EMPTY1",
    "KEY_EMPTY2_FILLED",
    "KEY_EMPTY2",
    "KEY_EMPTY3_FILLED",
    "KEY_EMPTY3",
    "KEY_MENU_FILLED",
    "KEY_MENU",
    "KEY_OPTION_FILLED",
    "KEY_OPTION",
    "KEY_RETURN_FILLED",
    "KEY_RETURN",
    "KEY_RING_FILLED",
    "KEY_RING",
    "KEY_SHIFT_FILLED",
    "KEY_SHIFT",
    "KEY_TAB_FILLED",
    "KEY_TAB",
    "KEY_WINDOWS_FILLED",
    "KEY_WINDOWS",
    "FUND",
    "HEART",
    "INTERNET_OFFLINE",
    "INTERNET",
    "USER",
    "EXPERIMENTAL",
    "MEMORY",
    "KEYTYPE_KEYFRAME_VEC",
    "KEYTYPE_BREAKDOWN_VEC",
    "KEYTYPE_EXTREME_VEC",
    "KEYTYPE_JITTER_VEC",
    "KEYTYPE_MOVING_HOLD_VEC",
    "KEYTYPE_GENERATED_VEC",
    "HANDLETYPE_FREE_VEC",
    "HANDLETYPE_ALIGNED_VEC",
    "HANDLETYPE_VECTOR_VEC",
    "HANDLETYPE_AUTO_VEC",
    "HANDLETYPE_AUTO_CLAMP_VEC",
    "COLORSET_01_VEC",
    "COLORSET_02_VEC",
    "COLORSET_03_VEC",
    "COLORSET_04_VEC",
    "COLORSET_05_VEC",
    "COLORSET_06_VEC",
    "COLORSET_07_VEC",
    "COLORSET_08_VEC",
    "COLORSET_09_VEC",
    "COLORSET_10_VEC",
    "COLORSET_11_VEC",
    "COLORSET_12_VEC",
    "COLORSET_13_VEC",
    "COLORSET_14_VEC",
    "COLORSET_15_VEC",
    "COLORSET_16_VEC",
    "COLORSET_17_VEC",
    "COLORSET_18_VEC",
    "COLORSET_19_VEC",
    "COLORSET_20_VEC",
    "COLLECTION_COLOR_01",
    "COLLECTION_COLOR_02",
    "COLLECTION_COLOR_03",
    "COLLECTION_COLOR_04",
    "COLLECTION_COLOR_05",
    "COLLECTION_COLOR_06",
    "COLLECTION_COLOR_07",
    "COLLECTION_COLOR_08",
    "SEQUENCE_COLOR_01",
    "SEQUENCE_COLOR_02",
    "SEQUENCE_COLOR_03",
    "SEQUENCE_COLOR_04",
    "SEQUENCE_COLOR_05",
    "SEQUENCE_COLOR_06",
    "SEQUENCE_COLOR_07",
    "SEQUENCE_COLOR_08",
    "SEQUENCE_COLOR_09",
    "LIBRARY_DATA_INDIRECT",
    "LIBRARY_DATA_OVERRIDE_NONEDITABLE",
    "LAYERGROUP_COLOR_01",
    "LAYERGROUP_COLOR_02",
    "LAYERGROUP_COLOR_03",
    "LAYERGROUP_COLOR_04",
    "LAYERGROUP_COLOR_05",
    "LAYERGROUP_COLOR_06",
    "LAYERGROUP_COLOR_07",
    "LAYERGROUP_COLOR_08",
    "EVENT_A",
    "EVENT_B",
    "EVENT_C",
    "EVENT_D",
    "EVENT_E",
    "EVENT_F",
    "EVENT_G",
    "EVENT_H",
    "EVENT_I",
    "EVENT_J",
    "EVENT_K",
    "EVENT_L",
    "EVENT_M",
    "EVENT_N",
    "EVENT_O",
    "EVENT_P",
    "EVENT_Q",
    "EVENT_R",
    "EVENT_S",
    "EVENT_T",
    "EVENT_U",
    "EVENT_V",
    "EVENT_W",
    "EVENT_X",
    "EVENT_Y",
    "EVENT_Z",
    "EVENT_SHIFT",
    "EVENT_CTRL",
    "EVENT_ALT",
    "EVENT_OS",
    "EVENT_F1",
    "EVENT_F2",
    "EVENT_F3",
    "EVENT_F4",
    "EVENT_F5",
    "EVENT_F6",
    "EVENT_F7",
    "EVENT_F8",
    "EVENT_F9",
    "EVENT_F10",
    "EVENT_F11",
    "EVENT_F12",
    "EVENT_F13",
    "EVENT_F14",
    "EVENT_F15",
    "EVENT_F16",
    "EVENT_F17",
    "EVENT_F18",
    "EVENT_F19",
    "EVENT_F20",
    "EVENT_F21",
    "EVENT_F22",
    "EVENT_F23",
    "EVENT_F24",
    "EVENT_ESC",
    "EVENT_TAB",
    "EVENT_PAGEUP",
    "EVENT_PAGEDOWN",
    "EVENT_RETURN",
    "EVENT_SPACEKEY",
    "EVENT_ZEROKEY",
    "EVENT_ONEKEY",
    "EVENT_TWOKEY",
    "EVENT_THREEKEY",
    "EVENT_FOURKEY",
    "EVENT_FIVEKEY",
    "EVENT_SIXKEY",
    "EVENT_SEVENKEY",
    "EVENT_EIGHTKEY",
    "EVENT_NINEKEY",
    "EVENT_PAD0",
    "EVENT_PAD1",
    "EVENT_PAD2",
    "EVENT_PAD3",
    "EVENT_PAD4",
    "EVENT_PAD5",
    "EVENT_PAD6",
    "EVENT_PAD7",
    "EVENT_PAD8",
    "EVENT_PAD9",
    "EVENT_PADASTER",
    "EVENT_PADSLASH",
    "EVENT_PADMINUS",
    "EVENT_PADENTER",
    "EVENT_PADPLUS",
    "EVENT_PADPERIOD",
    "EVENT_MOUSE_4",
    "EVENT_MOUSE_5",
    "EVENT_MOUSE_6",
    "EVENT_MOUSE_7",
    "EVENT_TABLET_STYLUS",
    "EVENT_TABLET_ERASER",
    "EVENT_LEFT_ARROW",
    "EVENT_DOWN_ARROW",
    "EVENT_RIGHT_ARROW",
    "EVENT_UP_ARROW",
    "EVENT_PAUSE",
    "EVENT_INSERT",
    "EVENT_HOME",
    "EVENT_END",
    "EVENT_UNKNOWN",
    "EVENT_GRLESS",
    "EVENT_MEDIAPLAY",
    "EVENT_MEDIASTOP",
    "EVENT_MEDIAFIRST",
    "EVENT_MEDIALAST",
    "EVENT_APP",
    "EVENT_CAPSLOCK",
    "EVENT_BACKSPACE",
    "EVENT_DEL",
    "EVENT_SEMICOLON",
    "EVENT_PERIOD",
    "EVENT_COMMA",
    "EVENT_QUOTE",
    "EVENT_ACCENTGRAVE",
    "EVENT_MINUS",
    "EVENT_PLUS",
    "EVENT_SLASH",
    "EVENT_BACKSLASH",
    "EVENT_EQUAL",
    "EVENT_LEFTBRACKET",
    "EVENT_RIGHTBRACKET",
    "EVENT_NDOF_BUTTON_V1",
    "EVENT_NDOF_BUTTON_V2",
    "EVENT_NDOF_BUTTON_V3",
    "EVENT_NDOF_BUTTON_SAVE_V1",
    "EVENT_NDOF_BUTTON_SAVE_V2",
    "EVENT_NDOF_BUTTON_SAVE_V3",
    "EVENT_NDOF_BUTTON_1",
    "EVENT_NDOF_BUTTON_2",
    "EVENT_NDOF_BUTTON_3",
    "EVENT_NDOF_BUTTON_4",
    "EVENT_NDOF_BUTTON_5",
    "EVENT_NDOF_BUTTON_6",
    "EVENT_NDOF_BUTTON_7",
    "EVENT_NDOF_BUTTON_8",
    "EVENT_NDOF_BUTTON_9",
    "EVENT_NDOF_BUTTON_10",
    "EVENT_NDOF_BUTTON_11",
    "EVENT_NDOF_BUTTON_12",
    "EVENT_NDOF_BUTTON_MENU",
    "EVENT_NDOF_BUTTON_FIT",
    "EVENT_NDOF_BUTTON_TOP",
    "EVENT_NDOF_BUTTON_BOTTOM",
    "EVENT_NDOF_BUTTON_LEFT",
    "EVENT_NDOF_BUTTON_RIGHT",
    "EVENT_NDOF_BUTTON_FRONT",
    "EVENT_NDOF_BUTTON_BACK",
    "EVENT_NDOF_BUTTON_ISO1",
    "EVENT_NDOF_BUTTON_ISO2",
    "EVENT_NDOF_BUTTON_ROLL_CW",
    "EVENT_NDOF_BUTTON_ROLL_CCW",
    "EVENT_NDOF_BUTTON_SPIN_CW",
    "EVENT_NDOF_BUTTON_SPIN_CCW",
    "EVENT_NDOF_BUTTON_TILT_CW",
    "EVENT_NDOF_BUTTON_TILT_CCW",
    "EVENT_NDOF_BUTTON_ROTATE",
    "EVENT_NDOF_BUTTON_PANZOOM",
    "EVENT_NDOF_BUTTON_DOMINANT",
    "EVENT_NDOF_BUTTON_PLUS",
    "EVENT_NDOF_BUTTON_MINUS",
]
type UilistLayoutTypeItems = typing.Literal["DEFAULT", "COMPACT", "GRID"]
type KeymapPropvalueItems = typing.Literal["NONE"]
type LightprobesTypeItems = typing.Literal["SPHERE", "PLANE", "VOLUME"]
type RegionTypeItems = typing.Literal[
    "WINDOW",
    "HEADER",
    "CHANNELS",
    "TEMPORARY",
    "UI",
    "TOOLS",
    "TOOL_PROPS",
    "ASSET_SHELF",
    "ASSET_SHELF_HEADER",
    "PREVIEW",
    "HUD",
    "NAVIGATION_BAR",
    "EXECUTE",
    "FOOTER",
    "TOOL_HEADER",
    "XR",
]
type NodeGeometryCurveHandleSideItems = typing.Literal["LEFT", "RIGHT"]
type ObjectTypeCurveItems = typing.Literal["CURVE", "SURFACE", "FONT"]
type NodeWarningTypeItems = typing.Literal["ERROR", "WARNING", "INFO"]
type ObjectModeItems = typing.Literal[
    "OBJECT",
    "EDIT",
    "POSE",
    "SCULPT",
    "VERTEX_PAINT",
    "WEIGHT_PAINT",
    "TEXTURE_PAINT",
    "PARTICLE_EDIT",
    "EDIT_GPENCIL",
    "SCULPT_GPENCIL",
    "PAINT_GPENCIL",
    "WEIGHT_GPENCIL",
    "VERTEX_GPENCIL",
    "SCULPT_CURVES",
]
type KeyframeHandleTypeItems = typing.Literal[
    "FREE", "ALIGNED", "VECTOR", "AUTO", "AUTO_CLAMPED"
]
type DtMethodLoopItems = typing.Literal[
    "TOPOLOGY",
    "NEAREST_NORMAL",
    "NEAREST_POLYNOR",
    "NEAREST_POLY",
    "POLYINTERP_NEAREST",
    "POLYINTERP_LNORPROJ",
]
type AxisXyzItems = typing.Literal["X", "Y", "Z"]
type ModifierTriangulateQuadMethodItems = typing.Literal[
    "BEAUTY", "FIXED", "FIXED_ALTERNATE", "SHORTEST_DIAGONAL", "LONGEST_DIAGONAL"
]
type OperatorTypeFlagItems = typing.Literal[
    "REGISTER",
    "UNDO",
    "UNDO_GROUPED",
    "BLOCKING",
    "MACRO",
    "GRAB_CURSOR",
    "GRAB_CURSOR_X",
    "GRAB_CURSOR_Y",
    "DEPENDS_ON_CURSOR",
    "PRESET",
    "INTERNAL",
    "MODAL_PRIORITY",
]
type GeometryNodesLinearGizmoDrawStyleItems = typing.Literal["ARROW", "CROSS", "BOX"]
type FmodifierTypeItems = typing.Literal[
    "NULL",
    "GENERATOR",
    "FNGENERATOR",
    "ENVELOPE",
    "CYCLES",
    "NOISE",
    "LIMITS",
    "STEPPED",
]
type SpaceImageModeItems = typing.Literal["IMAGE_EDITOR", "UV"]
type NlaModeExtendItems = typing.Literal["NOTHING", "HOLD", "HOLD_FORWARD"]
type SpaceGraphModeItems = typing.Literal["FCURVES", "DRIVERS"]
type RampBlendItems = typing.Literal[
    "MIX",
    "DARKEN",
    "MULTIPLY",
    "BURN",
    "LIGHTEN",
    "SCREEN",
    "DODGE",
    "ADD",
    "OVERLAY",
    "SOFT_LIGHT",
    "LINEAR_LIGHT",
    "DIFFERENCE",
    "EXCLUSION",
    "SUBTRACT",
    "DIVIDE",
    "HUE",
    "SATURATION",
    "COLOR",
    "VALUE",
]
type KeyframePasteOffsetValueItems = typing.Literal[
    "LEFT_KEY", "RIGHT_KEY", "CURRENT_FRAME", "CURSOR_VALUE", "NONE"
]
type VelocityUnitItems = typing.Literal["SECOND", "FRAME"]
type ModifierTriangulateNgonMethodItems = typing.Literal["BEAUTY", "CLIP"]
type KeyframePasteOffsetItems = typing.Literal["START", "END", "RELATIVE", "NONE"]
type AttributeDomainPointEdgeFaceCurveItems = typing.Literal[
    "POINT", "EDGE", "FACE", "CURVE"
]
type EventTypeMaskItems = typing.Literal[
    "KEYBOARD_MODIFIER",
    "KEYBOARD",
    "MOUSE_WHEEL",
    "MOUSE_GESTURE",
    "MOUSE_BUTTON",
    "MOUSE",
    "NDOF",
    "ACTIONZONE",
]
type PropertySubtypeNumberArrayItems = typing.Literal[
    "COLOR",
    "TRANSLATION",
    "DIRECTION",
    "VELOCITY",
    "ACCELERATION",
    "MATRIX",
    "EULER",
    "QUATERNION",
    "AXISANGLE",
    "XYZ",
    "XYZ_LENGTH",
    "COLOR_GAMMA",
    "COORDINATES",
    "LAYER",
    "LAYER_MEMBER",
    "NONE",
]
type WindowCursorItems = typing.Literal[
    "DEFAULT",
    "NONE",
    "WAIT",
    "CROSSHAIR",
    "MOVE_X",
    "MOVE_Y",
    "KNIFE",
    "TEXT",
    "PAINT_BRUSH",
    "PAINT_CROSS",
    "DOT",
    "ERASER",
    "HAND",
    "HAND_POINT",
    "HAND_CLOSED",
    "SCROLL_X",
    "SCROLL_Y",
    "SCROLL_XY",
    "EYEDROPPER",
    "PICK_AREA",
    "STOP",
    "COPY",
    "CROSS",
    "MUTE",
    "ZOOM_IN",
    "ZOOM_OUT",
]
type AttributeDomainOnlyMeshItems = typing.Literal["POINT", "EDGE", "FACE", "CORNER"]
type NodeFloatToIntItems = typing.Literal["ROUND", "FLOOR", "CEILING", "TRUNCATE"]
type BakePassFilterTypeItems = typing.Literal[
    "NONE", "EMIT", "DIRECT", "INDIRECT", "COLOR", "DIFFUSE", "GLOSSY", "TRANSMISSION"
]
type SequenceSoundModifierTypeItems = typing.Literal["SOUND_EQUALIZER"]
type ShrinkwrapFaceCullItems = typing.Literal["OFF", "FRONT", "BACK"]
type PropertySubtypeItems = typing.Literal[
    "NONE",
    "FILE_PATH",
    "DIR_PATH",
    "FILE_NAME",
    "BYTE_STRING",
    "PASSWORD",
    "PIXEL",
    "UNSIGNED",
    "PERCENTAGE",
    "FACTOR",
    "ANGLE",
    "TIME",
    "TIME_ABSOLUTE",
    "DISTANCE",
    "DISTANCE_CAMERA",
    "POWER",
    "TEMPERATURE",
    "WAVELENGTH",
    "COLOR_TEMPERATURE",
    "FREQUENCY",
    "COLOR",
    "TRANSLATION",
    "DIRECTION",
    "VELOCITY",
    "ACCELERATION",
    "MATRIX",
    "EULER",
    "QUATERNION",
    "AXISANGLE",
    "XYZ",
    "XYZ_LENGTH",
    "COLOR_GAMMA",
    "COORDINATES",
    "LAYER",
    "LAYER_MEMBER",
]
type ColorAttributeDomainItems = typing.Literal["POINT", "CORNER"]
type MeshDelimitModeItems = typing.Literal["NORMAL", "MATERIAL", "SEAM", "SHARP", "UV"]
type Stereo3DDisplayItems = typing.Literal[
    "ANAGLYPH", "INTERLACE", "TIMESEQUENTIAL", "SIDEBYSIDE", "TOPBOTTOM"
]
type PropDynamicpaintTypeItems = typing.Literal["CANVAS", "BRUSH"]
type CollectionColorItems = typing.Literal[
    "NONE",
    "COLOR_01",
    "COLOR_02",
    "COLOR_03",
    "COLOR_04",
    "COLOR_05",
    "COLOR_06",
    "COLOR_07",
    "COLOR_08",
]
type AxisXyItems = typing.Literal["X", "Y"]
type MotionpathDisplayTypeItems = typing.Literal["CURRENT_FRAME", "RANGE"]
type RigidbodyConstraintTypeItems = typing.Literal[
    "FIXED", "POINT", "HINGE", "SLIDER", "PISTON", "GENERIC", "GENERIC_SPRING", "MOTOR"
]
type NodeFilterItems = typing.Literal[
    "SOFTEN",
    "SHARPEN",
    "SHARPEN_DIAMOND",
    "LAPLACE",
    "SOBEL",
    "PREWITT",
    "KIRSCH",
    "SHADOW",
]
type ViewsFormatItems = typing.Literal["INDIVIDUAL", "STEREO_3D"]
type AttributeCurvesDomainItems = typing.Literal["POINT", "CURVE"]
type GreasePencilSelectmodeItems = typing.Literal["POINT", "STROKE", "SEGMENT"]
type CurveFitMethodItems = typing.Literal["REFIT", "SPLIT"]
type ObjectTypeItems = typing.Literal[
    "MESH",
    "CURVE",
    "SURFACE",
    "META",
    "FONT",
    "CURVES",
    "POINTCLOUD",
    "VOLUME",
    "GPENCIL",
    "GREASEPENCIL",
    "ARMATURE",
    "LATTICE",
    "EMPTY",
    "LIGHT",
    "LIGHT_PROBE",
    "CAMERA",
    "SPEAKER",
]
type AttributeDomainOnlyMeshNoEdgeItems = typing.Literal["POINT", "FACE", "CORNER"]
type PropertyStringSearchFlagItems = typing.Literal["SORT", "SUGGESTION"]
type NodeCompareOperationItems = typing.Literal[
    "LESS_THAN",
    "LESS_EQUAL",
    "GREATER_THAN",
    "GREATER_EQUAL",
    "EQUAL",
    "NOT_EQUAL",
    "BRIGHTER",
    "DARKER",
]
type ObjectShaderfxTypeItems = typing.Literal[
    "FX_BLUR",
    "FX_COLORIZE",
    "FX_FLIP",
    "FX_GLOW",
    "FX_PIXEL",
    "FX_RIM",
    "FX_SHADOW",
    "FX_SWIRL",
    "FX_WAVE",
]
type ObjectGpencilTypeItems = typing.Literal[
    "EMPTY", "STROKE", "MONKEY", "LINEART_SCENE", "LINEART_COLLECTION", "LINEART_OBJECT"
]
type PreferenceSectionItems = typing.Literal[
    "INTERFACE",
    "VIEWPORT",
    "LIGHTS",
    "EDITING",
    "ANIMATION",
    "EXTENSIONS",
    "ADDONS",
    "THEMES",
    "INPUT",
    "NAVIGATION",
    "KEYMAP",
    "SYSTEM",
    "SAVE_LOAD",
    "FILE_PATHS",
    "EXPERIMENTAL",
]
type ImageColorModeItems = typing.Literal["BW", "RGB", "RGBA"]
type OperatorReturnItems = typing.Literal[
    "RUNNING_MODAL", "CANCELLED", "FINISHED", "PASS_THROUGH", "INTERFACE"
]
type BeztripleKeyframeTypeItems = typing.Literal[
    "KEYFRAME", "BREAKDOWN", "MOVING_HOLD", "EXTREME", "JITTER", "GENERATED"
]
type BrushGpencilSculptTypesItems = typing.Literal[
    "SMOOTH",
    "THICKNESS",
    "STRENGTH",
    "RANDOMIZE",
    "GRAB",
    "PUSH",
    "TWIST",
    "PINCH",
    "CLONE",
]
type PropertySubtypeNumberItems = typing.Literal[
    "PIXEL",
    "UNSIGNED",
    "PERCENTAGE",
    "FACTOR",
    "ANGLE",
    "TIME",
    "TIME_ABSOLUTE",
    "DISTANCE",
    "DISTANCE_CAMERA",
    "POWER",
    "TEMPERATURE",
    "WAVELENGTH",
    "COLOR_TEMPERATURE",
    "FREQUENCY",
    "NONE",
]
type AttributeDomainWithoutCornerItems = typing.Literal[
    "POINT", "EDGE", "FACE", "CURVE", "INSTANCE", "LAYER"
]
type NodeFloatCompareItems = typing.Literal[
    "LESS_THAN", "LESS_EQUAL", "GREATER_THAN", "GREATER_EQUAL", "EQUAL", "NOT_EQUAL"
]
type BeztripleInterpolationEasingItems = typing.Literal[
    "AUTO", "EASE_IN", "EASE_OUT", "EASE_IN_OUT"
]
type NormalSpaceItems = typing.Literal["OBJECT", "TANGENT"]
type ImageTypeItems = typing.Literal[
    "BMP",
    "IRIS",
    "PNG",
    "JPEG",
    "JPEG2000",
    "TARGA",
    "TARGA_RAW",
    "CINEON",
    "DPX",
    "OPEN_EXR_MULTILAYER",
    "OPEN_EXR",
    "HDR",
    "TIFF",
    "WEBP",
    "FFMPEG",
]



import typing
import collections.abc
import typing_extensions
import bpy.types

_GenericType1 = typing.TypeVar("_GenericType1")
_GenericType2 = typing.TypeVar("_GenericType2")

def flush_edits(
    override_context: bpy.types.Context | dict[str, typing.Any] = None,
    execution_context: int | str | None = None,
    undo: bool | None = None,
):
    """Flush edit data from active editing modes

    :type override_context: bpy.types.Context | dict[str, typing.Any]
    :type execution_context: int | str | None
    :type undo: bool | None
    """

def lib_id_fake_user_toggle(
    override_context: bpy.types.Context | dict[str, typing.Any] = None,
    execution_context: int | str | None = None,
    undo: bool | None = None,
):
    """Save this data-block even if it has no users

    :type override_context: bpy.types.Context | dict[str, typing.Any]
    :type execution_context: int | str | None
    :type undo: bool | None
    """

def lib_id_generate_preview(
    override_context: bpy.types.Context | dict[str, typing.Any] = None,
    execution_context: int | str | None = None,
    undo: bool | None = None,
):
    """Create an automatic preview for the selected data-block

    :type override_context: bpy.types.Context | dict[str, typing.Any]
    :type execution_context: int | str | None
    :type undo: bool | None
    """

def lib_id_generate_preview_from_object(
    override_context: bpy.types.Context | dict[str, typing.Any] = None,
    execution_context: int | str | None = None,
    undo: bool | None = None,
):
    """Create a preview for this asset by rendering the active object

    :type override_context: bpy.types.Context | dict[str, typing.Any]
    :type execution_context: int | str | None
    :type undo: bool | None
    """

def lib_id_load_custom_preview(
    override_context: bpy.types.Context | dict[str, typing.Any] = None,
    execution_context: int | str | None = None,
    undo: bool | None = None,
    *,
    filepath: str = "",
    hide_props_region: bool | None = True,
    check_existing: bool | None = False,
    filter_blender: bool | None = False,
    filter_backup: bool | None = False,
    filter_image: bool | None = True,
    filter_movie: bool | None = False,
    filter_python: bool | None = False,
    filter_font: bool | None = False,
    filter_sound: bool | None = False,
    filter_text: bool | None = False,
    filter_archive: bool | None = False,
    filter_btx: bool | None = False,
    filter_collada: bool | None = False,
    filter_alembic: bool | None = False,
    filter_usd: bool | None = False,
    filter_obj: bool | None = False,
    filter_volume: bool | None = False,
    filter_folder: bool | None = True,
    filter_blenlib: bool | None = False,
    filemode: int | None = 9,
    show_multiview: bool | None = False,
    use_multiview: bool | None = False,
    display_type: typing.Literal[
        "DEFAULT", "LIST_VERTICAL", "LIST_HORIZONTAL", "THUMBNAIL"
    ]
    | None = "DEFAULT",
    sort_method: str | None = "",
):
    """Choose an image to help identify the data-block visually

        :type override_context: bpy.types.Context | dict[str, typing.Any]
        :type execution_context: int | str | None
        :type undo: bool | None
        :param filepath: File Path, Path to file
        :type filepath: str
        :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
        :type hide_props_region: bool | None
        :param check_existing: Check Existing, Check and warn on overwriting existing files
        :type check_existing: bool | None
        :param filter_blender: Filter .blend files
        :type filter_blender: bool | None
        :param filter_backup: Filter .blend files
        :type filter_backup: bool | None
        :param filter_image: Filter image files
        :type filter_image: bool | None
        :param filter_movie: Filter movie files
        :type filter_movie: bool | None
        :param filter_python: Filter Python files
        :type filter_python: bool | None
        :param filter_font: Filter font files
        :type filter_font: bool | None
        :param filter_sound: Filter sound files
        :type filter_sound: bool | None
        :param filter_text: Filter text files
        :type filter_text: bool | None
        :param filter_archive: Filter archive files
        :type filter_archive: bool | None
        :param filter_btx: Filter btx files
        :type filter_btx: bool | None
        :param filter_collada: Filter COLLADA files
        :type filter_collada: bool | None
        :param filter_alembic: Filter Alembic files
        :type filter_alembic: bool | None
        :param filter_usd: Filter USD files
        :type filter_usd: bool | None
        :param filter_obj: Filter OBJ files
        :type filter_obj: bool | None
        :param filter_volume: Filter OpenVDB volume files
        :type filter_volume: bool | None
        :param filter_folder: Filter folders
        :type filter_folder: bool | None
        :param filter_blenlib: Filter Blender IDs
        :type filter_blenlib: bool | None
        :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
        :type filemode: int | None
        :param show_multiview: Enable Multi-View
        :type show_multiview: bool | None
        :param use_multiview: Use Multi-View
        :type use_multiview: bool | None
        :param display_type: Display Type

    DEFAULT
    Default -- Automatically determine display type for files.

    LIST_VERTICAL
    Short List -- Display files as short list.

    LIST_HORIZONTAL
    Long List -- Display files as a detailed list.

    THUMBNAIL
    Thumbnails -- Display files as thumbnails.
        :type display_type: typing.Literal['DEFAULT','LIST_VERTICAL','LIST_HORIZONTAL','THUMBNAIL'] | None
        :param sort_method: File sorting mode
        :type sort_method: str | None
    """

def lib_id_override_editable_toggle(
    override_context: bpy.types.Context | dict[str, typing.Any] = None,
    execution_context: int | str | None = None,
    undo: bool | None = None,
):
    """Set if this library override data-block can be edited

    :type override_context: bpy.types.Context | dict[str, typing.Any]
    :type execution_context: int | str | None
    :type undo: bool | None
    """

def lib_id_unlink(
    override_context: bpy.types.Context | dict[str, typing.Any] = None,
    execution_context: int | str | None = None,
    undo: bool | None = None,
):
    """Remove a usage of a data-block, clearing the assignment

    :type override_context: bpy.types.Context | dict[str, typing.Any]
    :type execution_context: int | str | None
    :type undo: bool | None
    """

def redo(
    override_context: bpy.types.Context | dict[str, typing.Any] = None,
    execution_context: int | str | None = None,
    undo: bool | None = None,
):
    """Redo previous action

    :type override_context: bpy.types.Context | dict[str, typing.Any]
    :type execution_context: int | str | None
    :type undo: bool | None
    """

def undo(
    override_context: bpy.types.Context | dict[str, typing.Any] = None,
    execution_context: int | str | None = None,
    undo: bool | None = None,
):
    """Undo previous action

    :type override_context: bpy.types.Context | dict[str, typing.Any]
    :type execution_context: int | str | None
    :type undo: bool | None
    """

def undo_history(
    override_context: bpy.types.Context | dict[str, typing.Any] = None,
    execution_context: int | str | None = None,
    undo: bool | None = None,
    *,
    item: int | None = 0,
):
    """Redo specific action in history

    :type override_context: bpy.types.Context | dict[str, typing.Any]
    :type execution_context: int | str | None
    :type undo: bool | None
    :param item: Item
    :type item: int | None
    """

def undo_push(
    override_context: bpy.types.Context | dict[str, typing.Any] = None,
    execution_context: int | str | None = None,
    undo: bool | None = None,
    *,
    message: str = "Add an undo step *function may be moved*",
):
    """Add an undo state (internal use only)

    :type override_context: bpy.types.Context | dict[str, typing.Any]
    :type execution_context: int | str | None
    :type undo: bool | None
    :param message: Undo Message
    :type message: str
    """

def undo_redo(
    override_context: bpy.types.Context | dict[str, typing.Any] = None,
    execution_context: int | str | None = None,
    undo: bool | None = None,
):
    """Undo and redo previous action

    :type override_context: bpy.types.Context | dict[str, typing.Any]
    :type execution_context: int | str | None
    :type undo: bool | None
    """
